==> laktory-0.5.11.tar.gz: laktory-0.5.11/laktory/resources/quickstart-stacks/workflows/scripts/debug_pl.py <==
import sys
import importlib

from databricks.connect import DatabricksSession
from laktory import models
from laktory import settings


# --------------------------------------------------------------------------- #
# Setup                                                                       #
# --------------------------------------------------------------------------- #

stack_filepath = "../stack.yaml"

# Laktory root on DBFS, required to read checkpoints
settings.laktory_root = "/laktory/"

spark = DatabricksSession.builder.clusterId("TODO: Fill cluster ID").getOrCreate()

udf_dirpath = "../workspacefiles/pipelines/"

node_name = None

# --------------------------------------------------------------------------- #
# Get Pipeline                                                                #
# --------------------------------------------------------------------------- #


with open(stack_filepath, "r") as fp:
    stack = models.Stack.model_validate_yaml(fp)

pl = stack.get_env("dev").resources.pipelines["pl-stocks-job"]

print(pl)


# --------------------------------------------------------------------------- #
# Read UDFs                                                                   #
# --------------------------------------------------------------------------- #

# Import User Defined Functions
udfs = []
sys.path.append(udf_dirpath)
for udf in pl.udfs:
    module = importlib.import_module(udf.module_name)
    udfs += [getattr(module, udf.function_name)]


# --------------------------------------------------------------------------- #
# Execute Pipeline                                                            #
# --------------------------------------------------------------------------- #

if node_name:
    pl.nodes_dict[node_name].execute(spark=spark, write_sinks=False, udfs=udfs)
else:
    pl.execute(spark=spark, write_sinks=False, udfs=udfs)

# --------------------------------------------------------------------------- #
# Display Results                                                             #
# --------------------------------------------------------------------------- #

if node_name:
    df = pl.nodes_dict[node_name].output_df
else:
    df = pl.nodes[-1].output_df
df.laktory.display()

==> laktory-0.8.4.tar.gz: laktory-0.8.4/laktory/resources/quickstart-stacks/workflows/scripts/debug_pl.py <==
from databricks.connect import DatabricksSession

import laktory as lk

# TODO: import any custom modules that register Narwhals namespace(s)

# --------------------------------------------------------------------------- #
# Setup                                                                       #
# --------------------------------------------------------------------------- #

stack_filepath = "../stack.yaml"

# Laktory root on DBFS, required to read checkpoints
lk.settings.laktory_root = "/laktory/"

# Get Remote Spark Session
# TODO: use your own profile
# https://docs.databricks.com/aws/en/dev-tools/databricks-connect/cluster-config
spark = DatabricksSession.builder.profile("default").getOrCreate()

node_name = "brz_stock_prices"

# --------------------------------------------------------------------------- #
# Get Pipeline                                                                #
# --------------------------------------------------------------------------- #


with open(stack_filepath, "r") as fp:
    stack = lk.models.Stack.model_validate_yaml(fp)

pl = stack.get_env("dev").resources.pipelines["pl-stocks-job"]

# --------------------------------------------------------------------------- #
# Execute Pipeline                                                            #
# --------------------------------------------------------------------------- #

if node_name:
    pl.nodes_dict[node_name].execute(write_sinks=False)
else:
    pl.execute(write_sinks=False)

# --------------------------------------------------------------------------- #
# Display Results                                                             #
# --------------------------------------------------------------------------- #

if node_name:
    df = pl.nodes_dict[node_name].output_df
else:
    df = pl.nodes[-1].output_df
df.laktory.display()
